#
# MSgraveyard-fishing.R, 21 Mar 25
#
# Data from:
# https://github.com/fabianoriccardi/killed-by-microsoft

library("colorspace")
library("jsonlite")
library("plyr")


par(bty="l")
par(las=1)
par(pch="+")
pal_col=rainbow(2)


MS=fromJSON("corpses.json", flatten=TRUE)

corpses=MS$corpses

corpses$dateOpen=as.Date(corpses$birthDate, format="%Y-%m-%d")
corpses$dateClose=as.Date(corpses$deathDate, format="%Y-%m-%d")

# Product lifetime
corpses$lifetime=as.numeric(corpses$dateClose-corpses$dateOpen+1)

# Dates not always given
corpses=subset(corpses, !is.na(lifetime))

soft_only=corpses

# Create a dataframe to make life easier
lifetime=data.frame(available=nrow(soft_only):1, age=sort(soft_only$lifetime))

plot(lifetime$age/365.25, lifetime$available, log="y", col=pal_col[2],
	xaxs="i",
	xlim=c(0, 36),
        xlab="Years since product launch", ylab="Products still in use")

MS_mod=glm(log(available) ~ age, data=lifetime,
					subset=(age > 100) & (age < 8000))
summary(MS_mod)

# Product half-life
half_life=log(0.5)/log(1+coef(MS_mod)[2])/365.25
#      age 
# 6.958004

x_bounds=100:8000

pred=exp(predict(MS_mod, newdata=data.frame(age=x_bounds)))

lines(x_bounds/365.25, pred, col=pal_col[1])

dev.copy(dev=png, file="MS-prod-surv-years.png")
dev.off()


# Plot numbe rof products launched/killed per year
born_year=count(1970+round(as.numeric(corpses$dateOpen)/365.25))
died_year=count(1970+round(as.numeric(corpses$dateClose)/365.25))

plot(died_year, type="h", col=pal_col[1], lwd=1.3,
	xaxs="i",
	xlim=c(1980, 2030),
	xlab="Year", ylab="Products")
lines(born_year, col=pal_col[2], lwd=1.5)

legend("topleft", legend=c("Killed products", "Launched products"),
                        fill=pal_col, border="white", bty="n", cex=1.3)

dev.copy(dev=png, file="MS-born-died.png")
dev.off()


